==> lyskom-1.7.1.tar.gz: lyskom-1.7.1/src/server/lyskomd.h <==
/*
 * $Id: lyskomd.h,v 0.10 1994/04/05 08:02:10 ceder Exp $
 * Copyright (C) 1991, 1992, 1993, 1994  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */
/*
 * $Id: lyskomd.h,v 0.10 1994/04/05 08:02:10 ceder Exp $
 */


/*
 * restart_kom is used to try to recover from an impossible error.
 * This function is in fact never called, unless some cosmic radiation
 * changes some pointers or suchlike.
 *
 * The msg string is sent as a mail to kom@lysator.liu.se
 * (At least one member in that group should not read his mail using kom...)
 */

#if defined(HAVE_VFPRINTF) && defined(HAVE_STDARG_H)
extern void
restart_kom(const char * format, ...);
#else
extern void
restart_kom();
#endif

==> lyskom-1.8.0.tar.gz: lyskom-1.8.0/src/server/lyskomd.h <==
/*
 * $Id: lyskomd.h,v 0.12 1995/11/02 21:48:46 ceder Exp $
 * Copyright (C) 1991, 1992, 1993, 1994, 1995  Lysator Academic Computer Association.
 *
 * This file is part of the LysKOM server.
 * 
 * LysKOM is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 1, or (at your option) 
 * any later version.
 * 
 * LysKOM is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with LysKOM; see the file COPYING.  If not, write to
 * Lysator, c/o ISY, Linkoping University, S-581 83 Linkoping, SWEDEN,
 * or the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
 * MA 02139, USA.
 *
 * Please mail bug reports to bug-lyskom@lysator.liu.se. 
 */

#ifndef LYSKOMD_H_INCLUDED
#define LYSKOMD_H_INCLUDED

#include "compiler.h"

/*
 * restart_kom is used to try to recover from an impossible error.
 * This function is in fact never called, unless some cosmic radiation
 * changes some pointers or suchlike.
 *
 * The msg string is sent as a mail to kom@lysator.liu.se
 * (At least one member in that group should not read his mail using kom...)
 */

#if defined(HAVE_VFPRINTF) && defined(HAVE_STDARG_H)
extern void
restart_kom(const char * format, ...) NORETURN;
#else
extern void
restart_kom() NORETURN;
#endif

#endif /* LYSKOMD_H_INCLUDED */
